summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--piglit.conf.example18
-rw-r--r--tests/cts_gl.py91
-rw-r--r--tests/cts_gles.py (renamed from tests/cts.py)14
3 files changed, 112 insertions, 11 deletions
diff --git a/piglit.conf.example b/piglit.conf.example
index 944d5d9ab..b95ff89f4 100644
--- a/piglit.conf.example
+++ b/piglit.conf.example
@@ -85,13 +85,23 @@ testB
; overrides the value set here.
;extra_args=--deqp-visibility hidden
-[cts]
-; path to the cts executable
-; can be overwritten by PIGLIT_CTS_BIN environment variable
+[cts_gles]
+; path to the cts opengles executable
+; can be overwritten by PIGLIT_CTS_GLES_BIN environment variable
;bin=/home/knuth/cts/cts/glcts
; Space-separated list of extra command line arguments for cts. The
-; option is not required. The environment variable PIGLIT_CTS_EXTRA_ARGS
+; option is not required. The environment variable PIGLIT_CTS_GLES_EXTRA_ARGS
+; overrides the value set here.
+;extra_args=--deqp-visibility hidden
+
+[cts_gl]
+; path to the cts opengl executable
+; can be overwritten by PIGLIT_CTS_GL_BIN environment variable
+;bin=/home/knuth/cts/cts/glcts
+
+; Space-separated list of extra command line arguments for cts. The
+; option is not required. The environment variable PIGLIT_CTS_GL_EXTRA_ARGS
; overrides the value set here.
;extra_args=--deqp-visibility hidden
diff --git a/tests/cts_gl.py b/tests/cts_gl.py
new file mode 100644
index 000000000..caefa1abb
--- /dev/null
+++ b/tests/cts_gl.py
@@ -0,0 +1,91 @@
+# Copyright (c) 2015 Intel Corporation
+
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
+"""Piglit integration for Khronos CTS tests.
+
+By default this will run GL30, GL31, GL32, GL33, GL40, GL41, GL42, GL43, GL44
+and GL45 test cases. Those desiring to run only a subset of them should consider
+using the -t or -x options to include or exclude tests.
+
+For example:
+./piglit run cts_gl -c foo -t GL30- would run only GL30 tests
+
+This integration requires some configuration in piglit.conf, or the use of
+environment variables.
+
+In piglit.conf one should set the following:
+[cts_gl]:bin -- Path to the glcts binary
+[cts_gl]:extra_args -- any extra arguments to be passed to cts (optional)
+
+Alternatively (or in addition, since environment variables have precedence),
+one could set:
+PIGLIT_CTS_GL_BIN -- environment equivalent of [cts_gl]:bin
+PIGLIT_CTS_GL_EXTRA_ARGS -- environment equivalent of [cts_gl]:extra_args
+
+"""
+
+from __future__ import (
+ absolute_import, division, print_function, unicode_literals
+)
+import itertools
+
+from framework.test import deqp
+
+__all__ = ['profile']
+
+_CTS_BIN = deqp.get_option('PIGLIT_CTS_GL_BIN', ('cts_gl', 'bin'))
+
+_EXTRA_ARGS = deqp.get_option('PIGLIT_CTS_GL_EXTRA_ARGS', ('cts_gl', 'extra_args'),
+ default='').split()
+
+
+class DEQPCTSTest(deqp.DEQPBaseTest):
+ deqp_bin = _CTS_BIN
+
+ @property
+ def extra_args(self):
+ return super(DEQPCTSTest, self).extra_args + \
+ [x for x in _EXTRA_ARGS if not x.startswith('--deqp-case')]
+
+# Add all of the suites by default, users can use filters to remove them.
+profile = deqp.make_profile( # pylint: disable=invalid-name
+ itertools.chain(
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL30-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL31-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL32-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL33-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL40-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL41-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL42-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL43-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL44-CTS-cases.txt', _EXTRA_ARGS)),
+ deqp.iter_deqp_test_cases(
+ deqp.gen_caselist_txt(_CTS_BIN, 'GL45-CTS-cases.txt', _EXTRA_ARGS)),
+ ),
+ DEQPCTSTest)
diff --git a/tests/cts.py b/tests/cts_gles.py
index 0e64e1b87..983c69479 100644
--- a/tests/cts.py
+++ b/tests/cts_gles.py
@@ -25,20 +25,20 @@ desiring to run only a subset of them should consider using the -t or -x
options to include or exclude tests.
For example:
-./piglit run cts -c foo -t ES3- would run only ES3 tests (note the dash to
+./piglit run cts_gles -c foo -t ES3- would run only ES3 tests (note the dash to
exclude ES31 tests)
This integration requires some configuration in piglit.conf, or the use of
environment variables.
In piglit.conf one should set the following:
-[cts]:bin -- Path to the glcts binary
-[cts]:extra_args -- any extra arguments to be passed to cts (optional)
+[cts_gles]:bin -- Path to the glcts binary
+[cts_gles]:extra_args -- any extra arguments to be passed to cts (optional)
Alternatively (or in addition, since environment variables have precedence),
one could set:
-PIGLIT_CTS_BIN -- environment equivalent of [cts]:bin
-PIGLIT_CTS_EXTRA_ARGS -- environment equivalent of [cts]:extra_args
+PIGLIT_CTS_GLES_BIN -- environment equivalent of [cts_gles]:bin
+PIGLIT_CTS_GLES_EXTRA_ARGS -- environment equivalent of [cts_gles]:extra_args
"""
@@ -51,9 +51,9 @@ from framework.test import deqp
__all__ = ['profile']
-_CTS_BIN = deqp.get_option('PIGLIT_CTS_BIN', ('cts', 'bin'))
+_CTS_BIN = deqp.get_option('PIGLIT_CTS_GLES_BIN', ('cts_gles', 'bin'))
-_EXTRA_ARGS = deqp.get_option('PIGLIT_CTS_EXTRA_ARGS', ('cts', 'extra_args'),
+_EXTRA_ARGS = deqp.get_option('PIGLIT_CTS_GLES_EXTRA_ARGS', ('cts_gles', 'extra_args'),
default='').split()